client

package
v0.0.0-...-bca4b21 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 6, 2026 License: BSD-3-Clause Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client handles XposedOrNot API requests

func NewClient

func NewClient() *Client

NewClient creates a new XposedOrNot API client

func (*Client) CheckEmail

func (c *Client) CheckEmail(email string) (*models.BreachResult, error)

CheckEmail checks if an email has been involved in breaches

func (*Client) CheckPassword

func (c *Client) CheckPassword(password string) (*models.PasswordCheckResult, error)

CheckPassword checks if a password has been exposed using anonymized hash

func (*Client) GetAnalytics

func (c *Client) GetAnalytics(email string) (*models.BreachAnalytics, error)

GetAnalytics gets detailed breach analytics for an email

func (*Client) ListBreaches

func (c *Client) ListBreaches() ([]models.BreachInfo, error)

ListBreaches returns all known breaches

Jump to