Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client handles XposedOrNot API requests
func (*Client) CheckEmail ¶
func (c *Client) CheckEmail(email string) (*models.BreachResult, error)
CheckEmail checks if an email has been involved in breaches
func (*Client) CheckPassword ¶
func (c *Client) CheckPassword(password string) (*models.PasswordCheckResult, error)
CheckPassword checks if a password has been exposed using anonymized hash
func (*Client) GetAnalytics ¶
func (c *Client) GetAnalytics(email string) (*models.BreachAnalytics, error)
GetAnalytics gets detailed breach analytics for an email
func (*Client) ListBreaches ¶
func (c *Client) ListBreaches() ([]models.BreachInfo, error)
ListBreaches returns all known breaches
Click to show internal directories.
Click to hide internal directories.